summaryrefslogtreecommitdiffstats
path: root/ppapi/proxy/interface_list.h
diff options
context:
space:
mode:
authorbrettw@chromium.org <brettw@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2011-10-20 23:09:28 +0000
committerbrettw@chromium.org <brettw@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2011-10-20 23:09:28 +0000
commitac4b54de7f49f4f0910b952888eb44fc55737195 (patch)
tree00fc8b7d9bb51ca71ee34d3befb20be85acc2a3c /ppapi/proxy/interface_list.h
parentd365a681dce7dca73ecbd682529a98b5505e9cdb (diff)
downloadchromium_src-ac4b54de7f49f4f0910b952888eb44fc55737195.zip
chromium_src-ac4b54de7f49f4f0910b952888eb44fc55737195.tar.gz
chromium_src-ac4b54de7f49f4f0910b952888eb44fc55737195.tar.bz2
Rename InterfaceID to ApiID and move the file.
This was originally in the proxy and had a 1:1 correspondence with an interface. Then we reused this for other stuff and then merged some interfaces into larger APIs (ppapi/thunk/*_api.h) so the name was no longer accurate. It was wrong to be in the proxy directory since directories at a "lower level" than the proxy (ppapi/shared_impl and webkit/plugins/ppapi) depended on it. This renames to ApiID (I avoided APIID since it looks like a define) which is the proper description of the class, and moved it to shared_impl. This fixes the deps since there are no longer any bad dependencies on the proxy directory. TEST=it compiles BUG=none Review URL: http://codereview.chromium.org/8333004 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@106619 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'ppapi/proxy/interface_list.h')
-rw-r--r--ppapi/proxy/interface_list.h22
1 files changed, 11 insertions, 11 deletions
diff --git a/ppapi/proxy/interface_list.h b/ppapi/proxy/interface_list.h
index 0290af9..f29198f 100644
--- a/ppapi/proxy/interface_list.h
+++ b/ppapi/proxy/interface_list.h
@@ -21,14 +21,14 @@ class InterfaceList {
static InterfaceList* GetInstance();
// Looks up the ID for the given interface name. Returns INTERFACE_ID_NONE if
// the interface string is not found.
- InterfaceID GetIDForPPBInterface(const std::string& name) const;
- InterfaceID GetIDForPPPInterface(const std::string& name) const;
+ ApiID GetIDForPPBInterface(const std::string& name) const;
+ ApiID GetIDForPPPInterface(const std::string& name) const;
// Looks up the factory function for the given ID. Returns NULL if not
// supported.
- InterfaceProxy::Factory GetFactoryForID(InterfaceID id) const;
+ InterfaceProxy::Factory GetFactoryForID(ApiID id) const;
// Returns the interface pointer for the given browser or plugin interface,
// or NULL if it's not supported.
@@ -38,24 +38,24 @@ class InterfaceList {
private:
struct InterfaceInfo {
InterfaceInfo()
- : id(INTERFACE_ID_NONE),
+ : id(API_ID_NONE),
iface(NULL) {
}
- InterfaceInfo(InterfaceID in_id, const void* in_interface)
+ InterfaceInfo(ApiID in_id, const void* in_interface)
: id(in_id),
iface(in_interface) {
}
- InterfaceID id;
+ ApiID id;
const void* iface;
};
typedef std::map<std::string, InterfaceInfo> NameToInterfaceInfoMap;
- void AddProxy(InterfaceID id, InterfaceProxy::Factory factory);
+ void AddProxy(ApiID id, InterfaceProxy::Factory factory);
- void AddPPB(const char* name, InterfaceID id, const void* iface);
- void AddPPP(const char* name, InterfaceID id, const void* iface);
+ void AddPPB(const char* name, ApiID id, const void* iface);
+ void AddPPP(const char* name, ApiID id, const void* iface);
// Old-style add functions. These should be removed when the rest of the
// proxies are converted over to using the new system.
@@ -65,7 +65,7 @@ class InterfaceList {
NameToInterfaceInfoMap name_to_browser_info_;
NameToInterfaceInfoMap name_to_plugin_info_;
- InterfaceProxy::Factory id_to_factory_[INTERFACE_ID_COUNT];
+ InterfaceProxy::Factory id_to_factory_[API_ID_COUNT];
DISALLOW_COPY_AND_ASSIGN(InterfaceList);
};
@@ -21,14 +21,14 @@ class InterfaceList {
static InterfaceList* GetInstance();
- // Looks up the ID for the given interface name. Returns INTERFACE_ID_NONE if
+ // Looks up the ID for the given interface name. Returns API_ID_NONE if
// the interface string is not found.